@@ -5,7 +5,7 @@ use warnings;
 package Dist::Inktly::Bovine;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.002';
+our $VERSION   = '0.003';
 
 use Text::Template;
 
@@ -28,8 +28,8 @@ our $AUTHORITY = 'cpan:{uc $author->{cpanid}}';
 our $VERSION   = '{$version}';
 
 use Moo;
-use Types::Standard -types;
-use namespace::sweep;
+use Types::Common qw( -types -sigs );
+use namespace::autoclean;
 
 1;
 
@@ -50,7 +50,7 @@ use namespace::sweep;
 {}=head1 BUGS
 
 Please report any bugs to
-L<http://rt.cpan.org/Dist/Display.html?Queue={URI::Escape::uri_escape($dist_name)}>.
+<https://github.com/{lc $author->{cpanid}}/p5-{lc URI::Escape::uri_escape($dist_name)}/issues>.
 
 {}=head1 SEE ALSO
 
@@ -76,10 +76,14 @@ EOF
 @prefix : <http://ontologi.es/doap-deps#>.
 
 `{$dist_name}`
-	:runtime-requirement    [ :on "Moo 1.000000"^^:CpanId ];
-	:runtime-requirement    [ :on "Types::Standard 0.022"^^:CpanId ];
-	:runtime-requirement    [ :on "namespace::sweep 0.006"^^:CpanId ];
-	:test-requirement       [ :on "Test::More 0.96"^^:CpanId ];
+	:runtime-requirement    [ :on "perl 5.010000"^^:CpanId ];
+	:runtime-requirement    [ :on "Moo 2.000000"^^:CpanId ];
+	:runtime-requirement    [ :on "Types::Standard 2.000000"^^:CpanId ];
+	:runtime-requirement    [ :on "namespace::autoclean"^^:CpanId ];
+	:test-requirement       [ :on "Test2::V0"^^:CpanId ];
+	:test-requirement       [ :on "Test2::Tools::Spec"^^:CpanId ];
+	:test-requirement       [ :on "Test2::Require::AuthorTesting"^^:CpanId ];
+	:test-requirement       [ :on "Test2::Require::Module"^^:CpanId ];
 	:develop-recommendation [ :on "Dist::Inkt 0.001"^^:CpanId ];
 	.
 EOF
@@ -111,7 +115,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2013 by Toby Inkster.
+This software is copyright (c) 2013-2022 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
